@@ -178,10 +178,12 @@ typedef struct TAGMAGMODEINFO {
     ULONG   ulVFPorch;          /* Vertical front porch in lines                            */
     ULONG   ulVSync;            /* Vertical Sync in lines                                   */
     ULONG   ulVBPorch;          /* Vertical back Porch in lines                             */
-    ULONG   ulDisplayOrg;       /* Origin of the display Offset(bytes)                      */
+    ULONG   ulDisplayOrg;       /* Origin of the display Offset(bytes)                                                       */
     ULONG   ulDstOrg;           /* Origin of the drawing Offset in the frame (bytes)        */
     ULONG   ulPanXGran;         /* Panning in X granularity in pixel                        */
     ULONG   ulPanYGran;         /* Panning in Y granularity in pixel                        */
+    ULONG   ulTVStandard;        /* TV Standard                                              */
+    ULONG   ulCableType;         /* Cable Type                                               */
 } MGAMODEINFO, FAR *LPMGAMODEINFO;
 
 #define MGAHWINFOCAPS_CRTC1_ANALOG          1L      
@@ -206,6 +208,19 @@ typedef struct TAGMAGMODEINFO {
 #define MGAMODEINFO_TV                 (1L << 7)
 #define MGAMODEINFO_TESTONLY           0x80000000
 
+/* Cable Type */
+#define TV_YC_COMPOSITE                 0
+#define TV_SCART_RGB                    1
+#define TV_SCART_COMPOSITE              2
+#define TV_SCART_TYPE2                  3
+
+/* TV Standard */
+
+#define TV_PAL                          0
+#define TV_NTSC                         1
+
+
+
 #if defined(__cplusplus)
     extern "C" {
 #endif
@@ -224,7 +239,8 @@ ULONG MGAGetHardwareInfo(LPBOARDHANDLE pBoard, LPMGAHWINFO pMgaHwInfo);
 LPVOID MGAGetClientPointer(LPBOARDHANDLE pBoard);
 ULONG MGAOpenLibrary(LPBOARDHANDLE pBoard, LPVOID lpClient, ULONG ulClientSize);
 ULONG MGAGetBOARDHANDLESize(void);
-
+ULONG MGASetTVStandard(LPBOARDHANDLE pBoard, ULONG ulTVStandard);
+ULONG MGASetTVCableType(LPBOARDHANDLE pBoard, ULONG ulCableType);
 #if defined(__cplusplus)
     }
 #endif
